==> foundation-ui-components-1.26.1.tgz: package/src/common/column-control/NsColumnControl.tsx <==
import { useMemo } from 'react';
import { Box } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';
import { NsColumnControlProps, sizeObjectType } from './types.d';
import { getColumnSizes } from './utils';
import { shouldNotForwardPropsWithKeys } from '../util';

type StyledDivProps = {
    sizes: sizeObjectType;
    gap?: number;
};

const options = {
    shouldForwardProp: shouldNotForwardPropsWithKeys<StyledDivProps>(['sizes']),
};

const descMaxWidthBreakpoints = [960, 600];

/* media queries */
const mediaQuery = descMaxWidthBreakpoints.map((bp) => `@media (max-width: ${bp}px)`);

const StyledDiv = styled(
    Box as any,
    options
)<StyledDivProps>(({ sizes, gap }: StyledDivProps) => {
    const gridTemplateColumns = sizes['fractions']?.map((e) => `${e}fr`).join(' ');
    const tabletTemplateColumns = sizes['tabletFractions']?.map((e) => `${e}fr`).join(' ');
    const mobileTemplateColumns = sizes['mobileFractions']?.map((e) => `${e}fr`).join(' ');
    return {
        display: 'grid',
        maxWidth: Array.isArray(sizes?.fractions) && sizes.fractions?.length <= 2 ? '1200px' : '2400px',
        margin: '32px auto',
        gap: gap ?? '2rem',
        overflow: 'scroll',
        gridTemplateColumns,
        [mediaQuery[0]]: {
            gridTemplateColumns: tabletTemplateColumns,
        },
        [mediaQuery[1]]: {
            gridTemplateColumns: mobileTemplateColumns,
        },
    };
});

const NsColumnControl = ({ columnClass, children, gap, additionalProps }: NsColumnControlProps) => {
    const sizes = useMemo(() => {
        return getColumnSizes(columnClass);
    }, [columnClass]);

    return (
        <StyledDiv
            sizes={sizes}
            gap={gap}
            data-testid={additionalProps?.testid ?? 'ns-column-control'}
            className={columnClass}
        >
            {children}
        </StyledDiv>
    );
};

export default NsColumnControl;

==> foundation-ui-components-1.30.1.tgz: package/src/common/column-control/NsColumnControl.tsx <==
import { ReactElement, useMemo } from 'react';

import { Box } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';

import { shouldNotForwardPropsWithKeys } from '../util';
import { NsColumnControlProps, sizeObjectType } from './types.d';
import { getColumnSizes } from './utils';

type StyledDivProps = {
    sizes: sizeObjectType;
    gap?: number;
};

const options = {
    shouldForwardProp: shouldNotForwardPropsWithKeys<StyledDivProps>(['sizes']),
};

const descMaxWidthBreakpoints = [960, 600];

/* media queries */
const mediaQuery = descMaxWidthBreakpoints.map((bp) => `@media (max-width: ${bp}px)`);

const StyledDiv = styled(
    Box as any,
    options
)<StyledDivProps>(({ sizes, gap }: StyledDivProps) => {
    const gridTemplateColumns = sizes['fractions']?.map((e) => `${e}fr`).join(' ');
    const tabletTemplateColumns = sizes['tabletFractions']?.map((e) => `${e}fr`).join(' ');
    const mobileTemplateColumns = sizes['mobileFractions']?.map((e) => `${e}fr`).join(' ');
    return {
        display: 'grid',
        maxWidth: Array.isArray(sizes?.fractions) && sizes.fractions?.length <= 2 ? '1200px' : '2400px',
        margin: '32px auto',
        gap: gap ?? '2rem',
        overflow: 'scroll',
        gridTemplateColumns,
        [mediaQuery[0]]: {
            gridTemplateColumns: tabletTemplateColumns,
        },
        [mediaQuery[1]]: {
            gridTemplateColumns: mobileTemplateColumns,
        },
    };
});

const NsColumnControl = ({ columnClass, children, gap, additionalProps }: NsColumnControlProps): ReactElement => {
    const sizes = useMemo(() => {
        return getColumnSizes(columnClass);
    }, [columnClass]);

    return (
        <StyledDiv
            sizes={sizes}
            gap={gap}
            data-testid={additionalProps?.testid ?? 'ns-column-control'}
            className={columnClass}
        >
            {children}
        </StyledDiv>
    );
};

export default NsColumnControl;
